package Bio::Variation;
$Bio::Variation::VERSION = '1.7.4';
use utf8;
use strict;
use warnings;

1;

# ABSTRACT: BioPerl variation-related functionality
# AUTHOR: See the individual modules for their authors.
# OWNER: See the individual modules for their copyright holders
# LICENSE: Perl_5

=head1 SYNOPSIS

See L<Bio::Perl> for examples.

=head1 DESCRIPTION

The code in this distribution focuses on simple low-dependency variant-related
functionality for BioPerl. See the specific modules for details.

=cut

__END__
